@@ -86,11 +86,11 @@ class Connection(object):
             if e.args[0] == errno.EPIPE:
                 self.disconnect()
             if isinstance(e.args, basestring):
-                errno, errmsg = 'UNKNOWN', e.args
+                _errno, errmsg = 'UNKNOWN', e.args
             else:
-                errno, errmsg = e.args
+                _errno, errmsg = e.args
             raise ConnectionError("Error %s while writing to socket. %s." % \
-                (errno, errmsg))
+                (_errno, errmsg))
 
     def read(self, length=None):
         """
@@ -218,7 +218,7 @@ class Redis(threading.local):
         string_keys_to_dict(
             'DECRBY GETBIT HLEN INCRBY LINSERT LLEN LPUSHX RPUSHX SCARD '
             'SDIFFSTORE SETBIT SETRANGE SINTERSTORE STRLEN SUNIONSTORE ZCARD '
-            'ZREMRANGEBYRANK ZREMRANGEBYSCORE ZREVRANK',
+            'ZREMRANGEBYRANK ZREMRANGEBYSCORE',
             int
             ),
         string_keys_to_dict(
@@ -237,6 +237,7 @@ class Redis(threading.local):
             lambda r: r and set(r) or set()
             ),
         string_keys_to_dict('ZRANGE ZRANGEBYSCORE ZREVRANGE', zset_score_pairs),
+        string_keys_to_dict('ZRANK ZREVRANK', int_or_none),
         {
             'BGREWRITEAOF': lambda r: \
                 r == 'Background rewriting of AOF file started',
@@ -249,7 +250,6 @@ class Redis(threading.local):
             'PING': lambda r: r == 'PONG',
             'RANDOMKEY': lambda r: r and r or None,
             'TTL': lambda r: r != -1 and r or None,
-            'ZRANK': int_or_none,
         }
         )
 
@@ -543,7 +543,7 @@ class Redis(threading.local):
         instance is promoted to a master instead.
         """
         if host is None and port is None:
-            return self.execute_command("SLAVEOF NO ONE")
+            return self.execute_command("SLAVEOF", "NO", "ONE")
         return self.execute_command("SLAVEOF", host, port)
 
     #### BASIC KEY COMMANDS ####
